#include <ansi_c.h>
/* This is a simple project that will call
 * functions from an external DLL */


#include <cvirte.h>    /* Needed if linking in external compiler; harmless otherwise */
#include <formatio.h>
#include <userint.h>
#include "icsnLW40.h"
#include <stdio.h>


icsSpyMessage	stMsgs[20000];	// buffer of messages used when reading
icsSpyMessageJ1850 	stTxMsg;	// message used for transmitting J1850 messages
icsSpyMessage 	stSTxMsg;		// message used for tranmsitting CAN messages

long hObject;		// handle to the neoVI driver object (this must be global or openport will fail)
	
int main (int argc, char *argv[])
{
	int bResult;				// used to test result from functions
	long lNumErrors;			// errors read from dll
	long lNumMessages;			// number of messages read
	int iCount;					// general purpose counter variable
	char cInput;				// general purpose character input
	unsigned char bNetIds[16];	// array of net ids
	unsigned char bSCPIds[256];	// array of scp functional ids
    
    // intialize the net id
	for (iCount=0;iCount<16;iCount++)
		bNetIds[iCount] = iCount;

	// print the header  
	for (iCount=0;iCount<16;iCount++)
		printf("\n"); // sixteen blank spaces  
    printf("neoVI CVI Example\n");
    printf("*********************************************\n");
	printf("COMMANDS\n");
	printf("Quit = q + enter\n");	
    printf("Transmit = t + enter\n");
	printf("Read Messages = any other key or enter by it self\n");    
	printf("\n");                                          
	printf("\n");
	                                          
	/* Open a Connection to the neoVI device */
    bResult = icsneoOpenPort(1 ,NEOVI_COMMTYPE_USB_BULK, INTREPIDCS_DRIVER_STANDARD, bNetIds, bSCPIds ,&hObject);

	
    // Test the Result
    if (bResult)
    {
    	printf("neoVI Opened Successfully\n");
    }
    else
    {
    	printf("Problem Opening neoVI, Exiting Program.\n");
    	return 0;
    }
    
    
    // main loop
    while (cInput != 'q')
    {
      cInput = getchar(); // get a character 
      if (cInput =='t')
      {
		// this is a transmit operation      	
		printf("Transmitting a Message on HS CAN\n");        

		// setup a simple can message
		stSTxMsg.ArbIDOrHeader = 0x100;
		stSTxMsg.NumberBytesData = 1; 
		stSTxMsg.Data[0]++;
		/*
		
		//use the commented out for transmitting on J1850 with a NETID_JVPW argument
		
		// setup a simple J1850 message
		stTxMsg.Header[0] = 0xFF;
		stTxMsg.Header[1] = 0x3F;
		stTxMsg.Header[2] = 0x40;		
		stTxMsg.NumberBytesHeader = 3;				
		stTxMsg.Data[0]++;
		stTxMsg.NumberBytesData = 1;

		memcpy(&stSTxMsg,&stTxMsg,sizeof(stSTxMsg)); //*/

		// transmit the message
		if (!icsneoTxMessages(hObject,&stSTxMsg,NETID_HSCAN,1))
    	{
    		printf("Problem Transmitting Message, Exiting Program.\n");
    		icsneoClosePort(hObject,&lNumErrors);
    		return 0;
    	}
		
      }
      else
      {
		// Read out the messages      	
      	if (!icsneoGetMessages(hObject,stMsgs,&lNumMessages,&lNumErrors))
    	{
    		printf("Problem Reading Messages from neoVI, Exiting Program.\n");
    		icsneoClosePort(hObject,&lNumErrors);
    		return 0;
    	}
      	
      	// Display a message of how many messages
      	printf("Reading %d Messages %d Errors\n",lNumMessages,lNumErrors);
      	// 	
      	for (iCount=0;iCount<lNumMessages;iCount++)
      	{
			// display the tx or rx message
			if (stMsgs[iCount].StatusBitField & SPY_STATUS_TX_MSG)
				printf("%d Tx Network %d ArbID %x DLC %d\n",iCount,stMsgs[iCount].NetworkID,stMsgs[iCount].ArbIDOrHeader,stMsgs[iCount].NumberBytesData);
			else
				printf("%d Rx Network %d ArbID %x DLC %d\n",iCount,stMsgs[iCount].NetworkID,stMsgs[iCount].ArbIDOrHeader,stMsgs[iCount].NumberBytesData);
      	}
      }
    };
    
    
	// close the neoVI port
	icsneoClosePort(hObject,&lNumErrors);
	
    return 0;
}

